@@ -7,6 +7,7 @@ from sqlalchemy import (
     ForeignKey,
     UniqueConstraint,
     String,
+    Boolean,
 )
 
 from ...database import Base
@@ -27,6 +28,7 @@ class InterventionFileModel(Base):
         nullable=False,
     )
     type = Column(String(50), nullable=False)
+    is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
