@@ -27,6 +27,8 @@ class SRCIdInterventionModel(Base):
     narrow = Column(Boolean, nullable=False)
     group = Column(Integer, nullable=False)
     is_deleted = Column(Boolean, nullable=True)
+    score = Column(Integer, nullable=True)
+    final_mapping = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
